import * as bodyParser from 'body-parser';
import cookieParser from 'cookie-parser';
import Debug from 'debug';
import express, { NextFunction, Request, Response } from 'express';
import createError from 'http-errors';
import requestLogger from 'morgan';

import indexApp from './routes/index';

const logInfo = Debug('api:info');
const app = express();

app.use(requestLogger('dev', { stream: { write: (msg: any) => logInfo(msg) } }));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: true }));
app.use(cookieParser());

app.use(process.env.APP_ROOT as string, indexApp);

// catch 404 and forward to error handler
app.use((req, res, next) => {
  next(createError(404));
});

// error handler
app.use((err: any, req: Request, res: Response, next: NextFunction) => {

  // only providing error in development
  const error = req.app.get('env') === 'development' ? err : {};

  res.status(err.status || 500);
  res.json({ message: err.message, error });

});

export = app;
